==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QChartView_shell.h <==
#ifndef QCHARTVIEW_SHELL_H
#define QCHARTVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qchartview.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtransform.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsview.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QChartView_shell : public QChartView, public QtJambiShellInterface
{
public:
    QChartView_shell(QChart* chart0, QWidget* parent1 = nullptr);
    QChartView_shell(QWidget* parent0 = nullptr);
    ~QChartView_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void drawBackground(QPainter* painter0, const QRectF& rect1) override;
    void drawForeground(QPainter* painter0, const QRectF& rect1) override;
    void drawItems(QPainter* painter0, int numItems1, QGraphicsItem** items2, const QStyleOptionGraphicsItem* options3) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* event0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* widget0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QChartView_access : public QChartView
{
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QCHARTVIEW_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiCharts/QChartView_shell.h <==
#ifndef QCHARTVIEW_SHELL_H
#define QCHARTVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qchartview.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtransform.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsview.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QChartView_shell : public QChartView, public QtJambiShellInterface
{
public:
    QChartView_shell(QChart* chart0, QWidget* parent1 = nullptr);
    QChartView_shell(QWidget* parent0 = nullptr);
    ~QChartView_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QChartView_mshell;
    friend class QChartView_oshell;
};


class QChartView_mshell : public QChartView_shell
{
public:
    using QChartView_shell::QChartView_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QChartView_oshell : public QChartView_mshell
{
public:
    using QChartView_mshell::QChartView_mshell;
    ~QChartView_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void drawBackground(QPainter* painter0, const QRectF& rect1) override;
    void drawForeground(QPainter* painter0, const QRectF& rect1) override;
    void drawItems(QPainter* painter0, int numItems1, QGraphicsItem** items2, const QStyleOptionGraphicsItem* options3) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* event0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* widget0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QChartView_access : public QChartView
{
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QCHARTVIEW_SHELL_H
